==> ucdp-0.6.0-py3-none-any.whl: ucdp/examples/simple/glbl_lib/clk_gate.py <==
#
# MIT License
#
# Copyright (c) 2024 nbiotcloud
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Clock Gate."""

from typing import ClassVar

import ucdp as u  # (1)
from fileliststandard import HdlFileList


class ClkGateMod(u.AMod):
    """Clock Gate."""

    # File Lists
    filelists: ClassVar[u.ModFileLists] = (  # (2)
        HdlFileList(),
    )

    def _build(self) -> None:
        # Port Declarations (3)
        self.add_port(u.ClkType(), "clk_i")
        self.add_port(u.ClkType(), "clk_o")
        self.add_port(u.EnaType(), "ena_i")

==> ucdp-0.18.1-py3-none-any.whl: ucdp/examples/simple/glbl_lib/clk_gate.py <==
#
# MIT License
#
# Copyright (c) 2024 nbiotcloud
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Clock Gate."""

import ucdp as u  # (1)
from fileliststandard import HdlFileList


class ClkGateMod(u.AMod):
    """Clock Gate."""

    # File Lists
    filelists: u.ClassVar[u.ModFileLists] = (  # (2)
        HdlFileList(),
    )

    def _build(self) -> None:
        # Port Declarations (3)
        self.add_port(u.ClkType(), "clk_i")
        self.add_port(u.ClkType(), "clk_o")
        self.add_port(u.EnaType(), "ena_i")
